dival.datasets package
======================

Submodules
----------

.. toctree::

   dival.datasets.dataset
   dival.datasets.ellipses_dataset
   dival.datasets.lodopab_dataset
   dival.datasets.standard

Module contents
---------------

.. automodule:: dival.datasets
   :members:
   :undoc-members:
   :show-inheritance:
